@@ -1,5 +1,5 @@
 from pymasmovil.client import Client
-from pymasmovil.errors.authentication_error import AuthenticationError
+from pymasmovil.errors.exceptions import MissingLoginCredentialsError, AutenthicationError
 import os
 
 
@@ -16,14 +16,19 @@ class Session():
         login_params = (
             ('username', os.getenv('MM_USER')),
             ('password', os.getenv('MM_PASSWORD')),
-            ('domain', 'test'),
+            ('domain', os.getenv('MM_DOMAIN')),
         )
 
         if login_params[0][1] is None:
-            raise AuthenticationError('MM_USER')
+            raise MissingLoginCredentialsError('MM_USER')
         elif login_params[1][1] is None:
-            raise AuthenticationError('MM_PASSWORD')
+            raise MissingLoginCredentialsError('MM_PASSWORD')
+        elif login_params[2][1] is None:
+            raise MissingLoginCredentialsError('MM_DOMAIN')
 
         session = Client().post(route=route, params=login_params, body={})
 
+        if not session["sessionId"]:
+            raise AutenthicationError
+
         return Session(session["sessionId"])
